---
name: Bug report
about: Create a report to help us improve
title: ''
labels: ''
assignees: ''

---

### Setup

I am reporting a problem with GSEApy version, Python version, and operating
system as follows:

```python
import sys; print(sys.version)
import platform; print(platform.python_implementation()); print(platform.platform())
import gseapy; print(gseapy.__version__)
```

(*Please copy and run the above in your Python, and copy-and-paste the output*)

### Expected behaviour

(*Please fill this in*)

### Actual behaviour

(*Please fill this in, and provide any exception message in full*)

### Steps to reproduce

(*Please fill this in*)
